@@ -34,9 +34,8 @@ import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyDescriptor;
 import java.beans.PropertyVetoException;
+import java.lang.reflect.Method;
 import java.util.HashMap;
-import java.util.LinkedList;
-import java.util.List;
 import java.util.Map;
 
 import com.jgoodies.binding.value.AbstractValueModel;
@@ -267,7 +266,7 @@ import com.jgoodies.binding.value.ValueModel;
  * </ol>
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.28 $
+ * @version $Revision: 1.30 $
  *
  * @see     com.jgoodies.binding.beans.PropertyAdapter
  * @see     ValueModel
@@ -1028,10 +1027,9 @@ public class BeanAdapter<B> extends Model {
      * @param newBean   the bean after the change
      */
     private void forwardAllAdaptedValuesChanged(B oldBean, B newBean) {
-        List<SimplePropertyAdapter> copiedList =
-            new LinkedList<SimplePropertyAdapter>(propertyAdapters.values());
-        for (SimplePropertyAdapter adapter : copiedList) {
-            adapter.setBean0(oldBean, newBean);
+        Object[] adapters = propertyAdapters.values().toArray();
+        for (Object adapter : adapters) {
+            ((SimplePropertyAdapter) adapter).setBean0(oldBean, newBean);
         }
     }
 
@@ -1048,10 +1046,9 @@ public class BeanAdapter<B> extends Model {
      */
     private void forwardAllAdaptedValuesChanged() {
         B currentBean = getBean();
-        List<SimplePropertyAdapter> copiedList =
-            new LinkedList<SimplePropertyAdapter>(propertyAdapters.values());
-        for (SimplePropertyAdapter adapter : copiedList) {
-            adapter.fireChange(currentBean);
+        Object[] adapters = propertyAdapters.values().toArray();
+        for (Object adapter : adapters) {
+            ((SimplePropertyAdapter) adapter).fireChange(currentBean);
         }
     }
 
@@ -1446,10 +1443,20 @@ public class BeanAdapter<B> extends Model {
         @Override
         protected String paramString() {
             B bean = getBean();
+            String beanType = null;
             Object value = getValue();
-            PropertyDescriptor propertyDescriptor = getPropertyDescriptor(bean);
-            String beanType  = bean  == null ? null : bean.getClass().getName();
-            String valueType = value == null ? null : value.getClass().getName();
+            String valueType = null;
+            String propertyDescriptorName = null;
+            String propertyType = null;
+            Method propertySetter = null;
+            if (bean != null) {
+                beanType  = bean.getClass().getName();
+                valueType = value == null ? null : value.getClass().getName();
+                PropertyDescriptor propertyDescriptor = getPropertyDescriptor(bean);
+                propertyDescriptorName = propertyDescriptor.getName();
+                propertyType = propertyDescriptor.getPropertyType().getName();
+                propertySetter = propertyDescriptor.getWriteMethod();
+            }
             return
                   "bean="
                 + bean
@@ -1460,11 +1467,11 @@ public class BeanAdapter<B> extends Model {
                 + "; value type="
                 + valueType
                 + "; property name="
-                + propertyDescriptor.getName()
+                + propertyDescriptorName
                 + "; property type="
-                + propertyDescriptor.getPropertyType().getName()
+                + propertyType
                 + "; property setter="
-                + propertyDescriptor.getWriteMethod();
+                + propertySetter;
         }
 
 
