@@ -30,7 +30,6 @@
 
 package com.jgoodies.binding.beans;
 
-import java.awt.EventQueue;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeListenerProxy;
@@ -82,7 +81,7 @@ import java.beans.PropertyChangeSupport;
  * safely via #equals, for example Strings, Booleans and Numbers.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.12 $
+ * @version $Revision: 1.13 $
  *
  * @see PropertyChangeSupport
  * @see PropertyChangeEvent
@@ -106,11 +105,11 @@ public final class ExtendedPropertyChangeSupport extends PropertyChangeSupport {
     private final boolean checkIdentityDefault;
 
 
-    /**
-     * Describes whether this change support ensures that registered
-     * PropertyChangeListeners are notified in the event dispatch thread (EDT).
-     */
-    private final boolean ensureNotificationInEDT;
+//    /**
+//     * Describes whether this change support ensures that registered
+//     * PropertyChangeListeners are notified in the event dispatch thread (EDT).
+//     */
+//    private final boolean ensureNotificationInEDT;
 
 
     // Instance Creation ******************************************************
@@ -136,31 +135,33 @@ public final class ExtendedPropertyChangeSupport extends PropertyChangeSupport {
     public ExtendedPropertyChangeSupport(
         Object sourceBean,
         boolean checkIdentityDefault) {
-        this(sourceBean, checkIdentityDefault, false);
-    }
-
-
-    /**
-     * Constructs an ExtendedPropertyChangeSupport object
-     * with the specified default test method for differences between
-     * the old and new property values.
-     *
-     * @param sourceBean  The object provided as the source for any generated events.
-     * @param checkIdentityDefault true enables the identity check by default
-     * @param ensureNotificationInEDT   if true, this class ensures that
-     *     listeners are notified in the event dispatch thread (EDT)
-     */
-    public ExtendedPropertyChangeSupport(
-        Object sourceBean,
-        boolean checkIdentityDefault,
-        boolean ensureNotificationInEDT) {
         super(sourceBean);
         this.source = sourceBean;
         this.checkIdentityDefault = checkIdentityDefault;
-        this.ensureNotificationInEDT = ensureNotificationInEDT;
     }
 
 
+//    /**
+//     * Constructs an ExtendedPropertyChangeSupport object
+//     * with the specified default test method for differences between
+//     * the old and new property values.
+//     *
+//     * @param sourceBean  The object provided as the source for any generated events.
+//     * @param checkIdentityDefault true enables the identity check by default
+//     * @param ensureNotificationInEDT   if true, this class ensures that
+//     *     listeners are notified in the event dispatch thread (EDT)
+//     */
+//    public ExtendedPropertyChangeSupport(
+//        Object sourceBean,
+//        boolean checkIdentityDefault,
+//        boolean ensureNotificationInEDT) {
+//        super(sourceBean);
+//        this.source = sourceBean;
+//        this.checkIdentityDefault = checkIdentityDefault;
+//        this.ensureNotificationInEDT = ensureNotificationInEDT;
+//    }
+
+
     // Firing Events **********************************************************
 
     /**
@@ -219,17 +220,17 @@ public final class ExtendedPropertyChangeSupport extends PropertyChangeSupport {
         if (oldValue != null && oldValue == newValue) {
             return;
         }
-        if (!ensureNotificationInEDT || EventQueue.isDispatchThread()) {
-            firePropertyChange0(evt, checkIdentity);
-            return;
-        }
-        EventQueue.invokeLater(new Runnable() {
-            public void run() {
-                ExtendedPropertyChangeSupport.this.firePropertyChange0(
-                        evt,
-                        checkIdentity);
-            }
-        });
+//        if (!ensureNotificationInEDT || EventQueue.isDispatchThread()) {
+        firePropertyChange0(evt, checkIdentity);
+//            return;
+//        }
+//        EventQueue.invokeLater(new Runnable() {
+//            public void run() {
+//                ExtendedPropertyChangeSupport.this.firePropertyChange0(
+//                        evt,
+//                        checkIdentity);
+//            }
+//        });
     }
 
 
@@ -256,19 +257,19 @@ public final class ExtendedPropertyChangeSupport extends PropertyChangeSupport {
         if (oldValue != null && oldValue == newValue) {
             return;
         }
-        if (!ensureNotificationInEDT || EventQueue.isDispatchThread()) {
-            firePropertyChange0(propertyName, oldValue, newValue, checkIdentity);
-            return;
-        }
-        EventQueue.invokeLater(new Runnable() {
-            public void run() {
-                ExtendedPropertyChangeSupport.this.firePropertyChange0(
-                        propertyName,
-                        oldValue,
-                        newValue,
-                        checkIdentity);
-            }
-        });
+//        if (!ensureNotificationInEDT || EventQueue.isDispatchThread()) {
+        firePropertyChange0(propertyName, oldValue, newValue, checkIdentity);
+//            return;
+//        }
+//        EventQueue.invokeLater(new Runnable() {
+//            public void run() {
+//                ExtendedPropertyChangeSupport.this.firePropertyChange0(
+//                        propertyName,
+//                        oldValue,
+//                        newValue,
+//                        checkIdentity);
+//            }
+//        });
     }
 
 
