@@ -33,8 +33,8 @@ package com.jgoodies.binding.beans;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
+import java.util.ArrayList;
 import java.util.HashMap;
-import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
@@ -74,7 +74,7 @@ import com.jgoodies.binding.value.ValueModel;
  * </pre>
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.9 $
+ * @version $Revision: 1.10 $
  *
  * @see     PropertyChangeEvent
  * @see     PropertyChangeListener
@@ -144,7 +144,7 @@ public final class IndirectPropertyChangeSupport {
             throw new NullPointerException("The bean channel must not be null.");
 
         this.beanChannel = beanChannel;
-        listenerList = new LinkedList<PropertyChangeListener>();
+        listenerList = new ArrayList<PropertyChangeListener>();
         namedListeners = new HashMap<String, List<PropertyChangeListener>>();
 
         beanChannel.addValueChangeListener(new BeanChangeHandler());
@@ -259,7 +259,7 @@ public final class IndirectPropertyChangeSupport {
         }
         List<PropertyChangeListener> namedListenerList = namedListeners.get(propertyName);
         if (namedListenerList == null) {
-            namedListenerList = new LinkedList<PropertyChangeListener>();
+            namedListenerList = new ArrayList<PropertyChangeListener>();
             namedListeners.put(propertyName, namedListenerList);
         }
         namedListenerList.add(listener);
