@@ -34,6 +34,7 @@ import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyDescriptor;
 import java.beans.PropertyVetoException;
+import java.lang.reflect.Method;
 
 import com.jgoodies.binding.value.AbstractValueModel;
 import com.jgoodies.binding.value.ValueHolder;
@@ -219,7 +220,7 @@ import com.jgoodies.binding.value.ValueModel;
  * </ol>
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.17 $
+ * @version $Revision: 1.18 $
  *
  * @see     com.jgoodies.binding.beans.BeanAdapter
  * @see     ValueModel
@@ -751,10 +752,20 @@ public final class PropertyAdapter<B> extends AbstractValueModel {
     @Override
     protected String paramString() {
         B bean = getBean();
+        String beanType = null;
         Object value = getValue();
-        PropertyDescriptor propertyDescriptor = getPropertyDescriptor(bean);
-        String beanType  = bean  == null ? null : bean.getClass().getName();
-        String valueType = value == null ? null : value.getClass().getName();
+        String valueType = null;
+        String propertyDescriptorName = null;
+        String propertyType = null;
+        Method propertySetter = null;
+        if (bean != null) {
+            beanType  = bean.getClass().getName();
+            valueType = value == null ? null : value.getClass().getName();
+            PropertyDescriptor propertyDescriptor = getPropertyDescriptor(bean);
+            propertyDescriptorName = propertyDescriptor.getName();
+            propertyType = propertyDescriptor.getPropertyType().getName();
+            propertySetter = propertyDescriptor.getWriteMethod();
+        }
         return
               "bean="
             + bean
@@ -765,11 +776,11 @@ public final class PropertyAdapter<B> extends AbstractValueModel {
             + "; value type="
             + valueType
             + "; property name="
-            + propertyDescriptor.getName()
+            + propertyDescriptorName
             + "; property type="
-            + propertyDescriptor.getPropertyType().getName()
+            + propertyType
             + "; property setter="
-            + propertyDescriptor.getWriteMethod();
+            + propertySetter;
     }
 
 
