@@ -44,7 +44,7 @@ import com.jgoodies.binding.beans.Model;
  * <code>setValue(Object)</code> to get and set this model's value.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.8 $
+ * @version $Revision: 1.9 $
  *
  * @see com.jgoodies.binding.beans.ExtendedPropertyChangeSupport
  */
@@ -352,6 +352,33 @@ public abstract class AbstractValueModel extends Model implements ValueModel {
      */
     @Override
     public String toString() {
+        return getClass().getName() + "[" + paramString() + "]";
+    }
+
+
+    /**
+     * Returns a string representing the state of this model.
+     * This method is intended to be used only for debugging purposes,
+     * and the content and format of the returned string may vary between
+     * implementations. The returned string may be empty but may not be
+     * {@code null}.
+     *
+     * @return  a string representation of this model's state
+     * @since   2.0.3
+     */
+    protected String paramString() {
+        return "value=" + valueString();
+    }
+
+
+    /**
+     * Returns a string representing the value of this model.
+     * This method is intended to be used for debugging purposes only.
+     *
+     * @return a string representation of this model's value
+     * @since 2.0.3
+     */
+    protected String valueString() {
         try {
             Object value = getValue();
             return value == null ? "null" : value.toString();
