@@ -50,7 +50,7 @@ import com.jgoodies.binding.value.ValueModel;
  * A test case for class {@link com.jgoodies.binding.beans.BeanAdapter}.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.28 $
+ * @version $Revision: 1.29 $
  */
 public final class BeanAdapterTest extends TestCase {
 
@@ -1006,4 +1006,13 @@ public final class BeanAdapterTest extends TestCase {
     }
 
 
+    // Null Bean **************************************************************
+
+    public void testNullBean() {
+        BeanAdapter<TestBean> adapter = new BeanAdapter<TestBean>((TestBean) null, true);
+        ValueModel model = adapter.getValueModel("readWriteObjectProperty");
+        model.toString();
+    }
+
+
 }
