@@ -49,7 +49,7 @@ import com.jgoodies.binding.value.ValueModel;
  * A test case for class {@link PropertyAdapter}.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.26 $
+ * @version $Revision: 1.27 $
  */
 public final class PropertyAdapterTest extends TestCase {
 
@@ -807,4 +807,12 @@ public final class PropertyAdapterTest extends TestCase {
     }
 
 
+    // Null Bean **************************************************************
+
+    public void testNullBean() {
+        PropertyAdapter<TestBean> adapter = new PropertyAdapter<TestBean>((TestBean) null, "readWriteObjectProperty", true);
+        adapter.toString();
+    }
+
+
 }
