@@ -70,7 +70,7 @@ import com.jgoodies.forms.layout.LayoutMap;
  * Demonstrates how to bind different value types to Swing components.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.28 $
+ * @version $Revision: 1.29 $
  *
  * @see com.jgoodies.binding.adapter.BasicComponentFactory
  * @see com.jgoodies.binding.adapter.Bindings
@@ -171,20 +171,26 @@ public final class ComponentsExample extends TutorialApplication {
         ValueModel intChoiceModel = presentationModel.getModel(ExampleBean.PROPERTY_INT_CHOICE);
         leftIntRadio = BasicComponentFactory.createRadioButton(
                 intChoiceModel, ExampleBean.LEFT_INTEGER, "Left");
+        leftIntRadio.setMnemonic('L');
         centerIntRadio = BasicComponentFactory.createRadioButton(
                 intChoiceModel, ExampleBean.CENTER_INTEGER, "Center");
+        centerIntRadio.setMnemonic('C');
         rightIntRadio = BasicComponentFactory.createRadioButton(
                 intChoiceModel, ExampleBean.RIGHT_INTEGER, "Right");
+        rightIntRadio.setMnemonic('R');
         alignmentIntCombo = BasicComponentFactory.createComboBox(
                 new SelectionInList<Integer>(ExampleBean.INTEGER_CHOICES, intChoiceModel));
 
         ValueModel objectChoiceModel = presentationModel.getModel(ExampleBean.PROPERTY_OBJECT_CHOICE);
         leftObjectRadio = BasicComponentFactory.createRadioButton(
                 objectChoiceModel, ExampleBean.LEFT, "Left");
+        leftObjectRadio.setMnemonic('f');
         centerObjectRadio = BasicComponentFactory.createRadioButton(
                 objectChoiceModel, ExampleBean.CENTER, "Center");
+        centerObjectRadio.setMnemonic('n');
         rightObjectRadio = BasicComponentFactory.createRadioButton(
                 objectChoiceModel, ExampleBean.RIGHT, "Right");
+        rightObjectRadio.setMnemonic('h');
         alignmentObjectCombo = BasicComponentFactory.createComboBox(
                 new SelectionInList<Object>(ExampleBean.OBJECT_CHOICES, objectChoiceModel));
 
@@ -208,6 +214,7 @@ public final class ComponentsExample extends TutorialApplication {
         checkBox = BasicComponentFactory.createCheckBox(
                 presentationModel.getModel(ExampleBean.PROPERTY_BOOLEAN_VALUE),
                 "available");
+        checkBox.setMnemonic('a');
         colorPreview = new JPanel();
         colorPreview.setBorder(new LineBorder(Color.GRAY));
         updatePreviewPanel();
@@ -271,14 +278,14 @@ public final class ComponentsExample extends TutorialApplication {
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
         CellConstraints cc = new CellConstraints();
-        builder.addLabel("JTextField:",         cc.xy  (1, 1));
-        builder.add(textField,                  cc.xy  (3, 1));
-        builder.addLabel("JPasswordField:",     cc.xy  (1, 3));
-        builder.add(passwordField,              cc.xy  (3, 3));
-        builder.addLabel("JTextArea:",          cc.xy  (1, 5));
-        builder.add(new JScrollPane(textArea),  cc.xywh(3, 5, 1, 2));
-        builder.addLabel("JLabel:",             cc.xy  (1, 8));
-        builder.add(textLabel,                  cc.xy  (3, 8));
+        builder.addLabel("J&TextField:",         cc.xy  (1, 1));
+        builder.add(textField,                   cc.xy  (3, 1));
+        builder.addLabel("J&PasswordField:",     cc.xy  (1, 3));
+        builder.add(passwordField,               cc.xy  (3, 3));
+        builder.addLabel("JText&Area:",          cc.xy  (1, 5));
+        builder.add(new JScrollPane(textArea),   cc.xywh(3, 5, 1, 2));
+        builder.addLabel("J&Label:",             cc.xy  (1, 8));
+        builder.add(textLabel,                   cc.xy  (3, 8));
         return builder.getPanel();
     }
 
@@ -290,12 +297,12 @@ public final class ComponentsExample extends TutorialApplication {
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
         CellConstraints cc = new CellConstraints();
-        builder.addLabel("Date:",               cc.xy(1, 1));
-        builder.add(dateField,                  cc.xy(3, 1));
-        builder.addLabel("Integer:",            cc.xy(1, 3));
-        builder.add(integerField,               cc.xy(3, 3));
-        builder.addLabel("Long:",               cc.xy(1, 5));
-        builder.add(longField,                  cc.xy(3, 5));
+        builder.addLabel("&Date:",               cc.xy(1, 1));
+        builder.add(dateField,                   cc.xy(3, 1));
+        builder.addLabel("I&nteger:",            cc.xy(1, 3));
+        builder.add(integerField,                cc.xy(3, 3));
+        builder.addLabel("&Long:",               cc.xy(1, 5));
+        builder.add(longField,                   cc.xy(3, 5));
         return builder.getPanel();
     }
 
@@ -307,21 +314,21 @@ public final class ComponentsExample extends TutorialApplication {
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
         CellConstraints cc = new CellConstraints();
-        builder.addSeparator("Integer Choice",  cc.xyw(1,  1, 8));
-        builder.addLabel("JRadioButton:",       cc.xy (1,  3));
-        builder.add(leftIntRadio,               cc.xy (3,  3));
-        builder.add(centerIntRadio,             cc.xy (5,  3));
-        builder.add(rightIntRadio,              cc.xy (7,  3));
-        builder.addLabel("JComboBox:",          cc.xy (1,  5));
-        builder.add(alignmentIntCombo,          cc.xyw(3,  5, 3));
+        builder.addSeparator("Integer Choice",   cc.xyw(1,  1, 8));
+        builder.addLabel("JRadioButton:",        cc.xy (1,  3));
+        builder.add(leftIntRadio,                cc.xy (3,  3));
+        builder.add(centerIntRadio,              cc.xy (5,  3));
+        builder.add(rightIntRadio,               cc.xy (7,  3));
+        builder.addLabel("J&ComboBox:",          cc.xy (1,  5));
+        builder.add(alignmentIntCombo,           cc.xyw(3,  5, 3));
 
-        builder.addSeparator("Object Choice",   cc.xyw(1,  7, 8));
-        builder.addLabel("JRadioButton:",       cc.xy (1,  9));
-        builder.add(leftObjectRadio,            cc.xy (3,  9));
-        builder.add(centerObjectRadio,          cc.xy (5,  9));
-        builder.add(rightObjectRadio,           cc.xy (7,  9));
-        builder.addLabel("JComboBox:",          cc.xy (1, 11));
-        builder.add(alignmentObjectCombo,       cc.xyw(3, 11, 3));
+        builder.addSeparator("Object Choice",    cc.xyw(1,  7, 8));
+        builder.addLabel("JRadioButton:",        cc.xy (1,  9));
+        builder.add(leftObjectRadio,             cc.xy (3,  9));
+        builder.add(centerObjectRadio,           cc.xy (5,  9));
+        builder.add(rightObjectRadio,            cc.xy (7,  9));
+        builder.addLabel("JCombo&Box:",          cc.xy (1, 11));
+        builder.add(alignmentObjectCombo,        cc.xyw(3, 11, 3));
         return builder.getPanel();
     }
 
@@ -333,12 +340,12 @@ public final class ComponentsExample extends TutorialApplication {
         PanelBuilder builder = new PanelBuilder(layout);
         builder.setDefaultDialogBorder();
         CellConstraints cc = new CellConstraints();
-        builder.addLabel("JList:",              cc.xy(1, 1, "left, top"));
-        builder.add(new JScrollPane(list),      cc.xy(3, 1));
-        builder.addLabel("JTable:",             cc.xy(1, 3, "left, top"));
-        builder.add(new JScrollPane(table),     cc.xy(3, 3));
-        builder.addLabel("JComboBox:",          cc.xy(1, 5));
-        builder.add(comboBox,                   cc.xy(3, 5));
+        builder.addLabel("J&List:",              cc.xy(1, 1, "left, top"));
+        builder.add(new JScrollPane(list),       cc.xy(3, 1));
+        builder.addLabel("J&Table:",             cc.xy(1, 3, "left, top"));
+        builder.add(new JScrollPane(table),      cc.xy(3, 3));
+        builder.addLabel("J&ComboBox:",          cc.xy(1, 5));
+        builder.add(comboBox,                    cc.xy(3, 5));
         return builder.getPanel();
     }
 
@@ -356,16 +363,16 @@ public final class ComponentsExample extends TutorialApplication {
                 presentationModel.getModel(ExampleBean.PROPERTY_COLOR));
 
         CellConstraints cc = new CellConstraints();
-        builder.addLabel("JCheckBox:",         cc.xy(1, 1));
-        builder.add(checkBox,                  cc.xy(3, 1));
-        builder.addLabel("JSlider:",           cc.xy(1, 3));
-        builder.add(slider,                    cc.xy(3, 3));
-        builder.add(floatLabel,                cc.xy(5, 3));
-        builder.addLabel("JSpinner:",          cc.xy(1, 5));
-        builder.add(spinner,                   cc.xy(3, 5));
-        builder.addLabel("JColorChooser:",     cc.xy(1, 7));
-        builder.add(colorPreview,              cc.xy(3, 7, "fill, fill"));
-        builder.add(new JButton(chooseAction), cc.xy(5, 7, "left, center"));
+        builder.addLabel("JCheckBox:",          cc.xy(1, 1));
+        builder.add(checkBox,                   cc.xy(3, 1));
+        builder.addLabel("J&Slider:",           cc.xy(1, 3));
+        builder.add(slider,                     cc.xy(3, 3));
+        builder.add(floatLabel,                 cc.xy(5, 3));
+        builder.addLabel("JS&pinner:",          cc.xy(1, 5));
+        builder.add(spinner,                    cc.xy(3, 5));
+        builder.addLabel("J&ColorChooser:",     cc.xy(1, 7));
+        builder.add(colorPreview,               cc.xy(3, 7, "fill, fill"));
+        builder.add(new JButton(chooseAction),  cc.xy(5, 7, "left, center"));
         return builder.getPanel();
     }
 
