@@ -32,13 +32,10 @@ package com.jgoodies.binding.tutorial.manager;
 
 import java.util.List;
 
-import javax.swing.JComponent;
 import javax.swing.JFrame;
-import javax.swing.UIManager;
-import javax.swing.WindowConstants;
 
 import com.jgoodies.binding.tutorial.Album;
-import com.jgoodies.binding.tutorial.TutorialUtils;
+import com.jgoodies.binding.tutorial.TutorialApplication;
 
 /**
  * This is just a launcher class for the Album Manager example.
@@ -46,39 +43,31 @@ import com.jgoodies.binding.tutorial.TutorialUtils;
  * creates a JFrame and add the view as the frame's content.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.12 $
+ * @version $Revision: 1.14 $
  *
  * @see AlbumManagerView
  * @see AlbumManagerModel
  * @see com.jgoodies.binding.PresentationModel
  */
-public final class AlbumManagerExample {
-
-
-    private AlbumManagerExample() {
-        // Overrides default constructor; prevents instantiation.
-    }
+public final class AlbumManagerExample extends TutorialApplication {
 
 
     // Launching **************************************************************
 
     public static void main(String[] args) {
-        try {
-            UIManager.setLookAndFeel("com.jgoodies.looks.plastic.PlasticXPLookAndFeel");
-        } catch (Exception e) {
-            // Likely PlasticXP is not in the class path; ignore.
-        }
-        JFrame frame = new JFrame();
-        frame.setTitle("Binding Tutorial :: Album Manager");
-        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
+        TutorialApplication.launch(AlbumManagerExample.class, args);
+    }
+
+
+    @Override
+    protected void startup(String[] args) {
+        JFrame frame = createFrame("Binding Tutorial :: Album Manager");
         List<Album> exampleAlbums = Album.ALBUMS;
         AlbumManager albumManager = new AlbumManager(exampleAlbums);
         AlbumManagerModel model = new AlbumManagerModel(albumManager);
-        JComponent panel = new AlbumManagerView(model).buildPanel();
-        frame.getContentPane().add(panel);
-        frame.pack();
-        TutorialUtils.locateOnOpticalScreenCenter(frame);
-        frame.setVisible(true);
+        AlbumManagerView view = new AlbumManagerView(model);
+        frame.add(view.buildPanel());
+        packAndShowOnScreenCenter(frame);
     }
 
 
