@@ -57,7 +57,7 @@ import com.jgoodies.binding.tutorial.Album;
  * Actions for the Album operations: add, remove and edit the selected Album.
  *
  * @author  Karsten Lentzsch
- * @version $Revision: 1.17 $
+ * @version $Revision: 1.18 $
  *
  * @see AlbumManager
  * @see com.jgoodies.binding.PresentationModel
@@ -289,6 +289,7 @@ public final class AlbumManagerModel {
 
         private NewAction() {
             super("New\u2026");
+            putValue(Action.MNEMONIC_KEY, Integer.valueOf('N'));
         }
 
         public void actionPerformed(ActionEvent e) {
@@ -301,6 +302,7 @@ public final class AlbumManagerModel {
 
         private EditAction() {
             super("Edit\u2026");
+            putValue(Action.MNEMONIC_KEY, Integer.valueOf('E'));
         }
 
         public void actionPerformed(ActionEvent e) {
@@ -313,6 +315,7 @@ public final class AlbumManagerModel {
 
         private DeleteAction() {
             super("Delete");
+            putValue(Action.MNEMONIC_KEY, Integer.valueOf('D'));
         }
 
         public void actionPerformed(ActionEvent e) {
